==> haskell-ral-0.2-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ral.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ral
version:              0.2
visibility:           public
id:                   ral-0.2-9oZQHvLN6EvKA3KS535ef2
key:                  ral-0.2-9oZQHvLN6EvKA3KS535ef2
license:              GPL-2.0-or-later
copyright:            (c) 2019-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Random access lists
description:
    This package provides ordinary random access list, '\''RAList'\'', and also
    a length indexed variant, '\''RAVec'\''.

    The data structure allows fast cons-operation (like ordinary list) but also fast random access (like non-functional arrays).

    For @lens@ or @optics@ support see [ral-lens](https://hackage.haskell.org/package/ral-lens) and [ral-optics](https://hackage.haskell.org/package/ral-optics) packages respectively.

    === Similar packages

    This packages don'\''t provide length-indexed variant, and their '\''RAList'\'' has
    opaque structure.

    * https://hackage.haskell.org/package/ralist
    * https://hackage.haskell.org/package/random-access-list

category:             Data, Dependent Types, Singletons
abi:                  02e4850a83b59dbd5a15b2644088c655
exposed:              True
exposed-modules:
    Data.RAList Data.RAList.NonEmpty Data.RAList.Tree Data.RAVec
    Data.RAVec.NonEmpty Data.RAVec.Tree Data.RAVec.Tree.DF

hidden-modules:
    Data.RAList.Internal Data.RAList.NonEmpty.Internal
    Data.RAList.Tree.Internal TrustworthyCompat

import-dirs:          /usr/lib/ghc-8.10.4/site-local/ral-0.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/ral-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/ral-0.2
hs-libraries:         HSral-0.2-9oZQHvLN6EvKA3KS535ef2
depends:
    QuickCheck-2.14.2-1Bekdcpaoco52kkbfPlodE
    adjunctions-4.4-8bbrlDAajX2JHFw6M10C2P base-4.14.1.0
    bin-0.1.1-cAkiBv3n70LyDUcmXOb99 deepseq-1.4.4.0
    distributive-0.6.2.1-IhZmZaLS193G70FUbpTOj3
    fin-0.2-5HXXglqYMMVDNvyOQz5Z3X
    hashable-1.3.2.0-5x51STP8vZMKBx9J0CoY3R
    indexed-traversable-0.1.1-Dw8MIJyvCj8IZQDXOa8TBp
    semigroupoids-5.3.5-1TelkZhHTo1JLOnWhS5uiE

haddock-interfaces:   /usr/share/doc/haskell-ral/html/ral.haddock
haddock-html:         /usr/share/doc/haskell-ral/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ral-0.2-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ral.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ral
version:              0.2
visibility:           public
id:                   ral-0.2-2jwW5GT7256JazIrOousaM
key:                  ral-0.2-2jwW5GT7256JazIrOousaM
license:              GPL-2.0-or-later
copyright:            (c) 2019-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Random access lists
description:
    This package provides ordinary random access list, '\''RAList'\'', and also
    a length indexed variant, '\''RAVec'\''.

    The data structure allows fast cons-operation (like ordinary list) but also fast random access (like non-functional arrays).

    For @lens@ or @optics@ support see [ral-lens](https://hackage.haskell.org/package/ral-lens) and [ral-optics](https://hackage.haskell.org/package/ral-optics) packages respectively.

    === Similar packages

    This packages don'\''t provide length-indexed variant, and their '\''RAList'\'' has
    opaque structure.

    * https://hackage.haskell.org/package/ralist
    * https://hackage.haskell.org/package/random-access-list

category:             Data, Dependent Types, Singletons
abi:                  412fc281c3ae398f6e5ee84494ee721d
exposed:              True
exposed-modules:
    Data.RAList Data.RAList.NonEmpty Data.RAList.Tree Data.RAVec
    Data.RAVec.NonEmpty Data.RAVec.Tree Data.RAVec.Tree.DF

hidden-modules:
    Data.RAList.Internal Data.RAList.NonEmpty.Internal
    Data.RAList.Tree.Internal TrustworthyCompat

import-dirs:          /usr/lib/ghc-8.10.4/site-local/ral-0.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/ral-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/ral-0.2
hs-libraries:         HSral-0.2-2jwW5GT7256JazIrOousaM
depends:
    QuickCheck-2.14.2-1Bekdcpaoco52kkbfPlodE
    adjunctions-4.4-8ReL7HGZATLCotFyxcdQsH base-4.14.1.0
    bin-0.1.1-cAkiBv3n70LyDUcmXOb99 deepseq-1.4.4.0
    distributive-0.6.2.1-IhZmZaLS193G70FUbpTOj3
    fin-0.2-5HXXglqYMMVDNvyOQz5Z3X
    hashable-1.3.2.0-5x51STP8vZMKBx9J0CoY3R
    indexed-traversable-0.1.1-Dw8MIJyvCj8IZQDXOa8TBp
    semigroupoids-5.3.5-cGQX6w1Hy1Ht9Mtln6jkl

haddock-interfaces:   /usr/share/doc/haskell-ral/html/ral.haddock
haddock-html:         /usr/share/doc/haskell-ral/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
